[git] GpgOL - branch, nomapi, updated. gpgol-1.4.0-96-gcdf5d93

by Andre Heinecke cvs at cvs.gnupg.org
Tue Oct 18 15:24:04 CEST 2016


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GnuPG extension for MS Outlook".

The branch, nomapi has been updated
       via  cdf5d93e22ad19730a7bd31c3b751f8738b87bd4 (commit)
       via  20dace4ab5dd5e3e0590929698767327d8e5db70 (commit)
       via  bdc38c2c812fc4806927d3a574bea55c568a90a6 (commit)
       via  376084db0aa59c44a2ccc4e0f7878033fd76d2a6 (commit)
      from  51f5a2d9628c60ac490fbd5ee0c1511179ec74a0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit cdf5d93e22ad19730a7bd31c3b751f8738b87bd4
Author: Andre Heinecke <aheinecke at intevation.de>
Date:   Tue Oct 18 15:17:28 2016 +0200

    Improve sigdetails button and verify caching
    
    * src/gpgoladdin.cpp (GpgolRibbonExtender::GetIDsOfNames):
    (GpgolRibbonExtender::Invoke): Handle new icon callback.
    (GetCustomUI_MIME): Use new icon callback.
    * src/mail.cpp (Mail::Mail): New members for state caching.
    Rename m_uid to m_uuid to avoid confusion with the valid uid.
    (Mail::~Mail): Use renamed variables.
    (Mail::get_mail_for_uuid): Renamed.
    (Mail::decrypt_verify): Use renamed functions.
    (Mail::parsing_done): Add some traces for a crash.
    (Mail::update_sigstate): New. Called once after parsing done.
    (Mail::get_valid_sig): Use cached values.
    (Mail::is_valid_sig): Use cached values.
    (Mail::set_uuid): Renamed.
    (Mail::get_signature_status): Fix isOpenPGP
    (Mail::get_signature_icon_id): New. Use for new icons.
    (Mail::get_sig_fpr): New. Used for launch details.
    * src/mail.h: Update accordingly.
    * src/parsecontroller.cpp (ParseController::parse):
    Add some traces for a crash.
    * src/ribbon-callbacks.cpp (get_mail_from_control): Use renamed
    functions.
    (HRESULT launch_cert_details): Launch kleopatra on details.
    (HRESULT get_sigstate_icon): Get the Icon of a signature.
    * src/ribbon-callbacks.h: Update accordingly.

diff --git a/src/gpgoladdin.cpp b/src/gpgoladdin.cpp
index e8c5bd8..0b36f87 100644
--- a/src/gpgoladdin.cpp
+++ b/src/gpgoladdin.cpp
@@ -512,6 +512,7 @@ GpgolRibbonExtender::GetIDsOfNames (REFIID riid, LPOLESTR *rgszNames,
       ID_MAPPER (L"btnEncryptFileLarge", ID_BTN_ENCSIGN_LARGE)
       ID_MAPPER (L"btnSignLarge", ID_BTN_SIGN_LARGE)
       ID_MAPPER (L"btnVerifyLarge", ID_BTN_VERIFY_LARGE)
+      ID_MAPPER (L"btnSigstateLarge", ID_BTN_SIGSTATE_LARGE)
       ID_MAPPER (L"encryptBody", ID_CMD_ENCRYPT_BODY)
       ID_MAPPER (L"decryptBody", ID_CMD_DECRYPT_BODY)
       ID_MAPPER (L"addEncSignedAttachment", ID_CMD_ATT_ENCSIGN_FILE)
@@ -613,7 +614,7 @@ GpgolRibbonExtender::Invoke (DISPID dispid, REFIID riid, LCID lcid,
       case ID_GET_SIG_LABEL:
         return get_sig_label (parms->rgvarg[0].pdispVal, result);
       case ID_LAUNCH_CERT_DETAILS:
-        return launch_cert_details (parms->rgvarg[0].pdispVal, result);
+        return launch_cert_details (parms->rgvarg[0].pdispVal);
       case ID_GET_IS_SIGNED:
         return get_is_signed (parms->rgvarg[0].pdispVal, result);
 
@@ -636,6 +637,8 @@ GpgolRibbonExtender::Invoke (DISPID dispid, REFIID riid, LCID lcid,
       case ID_BTN_SIGN_LARGE:
       case ID_BTN_VERIFY_LARGE:
         return getIcon (dispid, result);
+      case ID_BTN_SIGSTATE_LARGE:
+        return get_sigstate_icon (parms->rgvarg[0].pdispVal, result);
     }
 
   log_debug ("%s:%s: leave", SRCNAME, __func__);
@@ -729,7 +732,7 @@ GetCustomUI_MIME (BSTR RibbonID, BSTR * RibbonXml)
         "     <group id=\"general\""
         "            label=\"%s\">"
         "       <button id=\"idSigned\""
-        "               getImage=\"btnSignLarge\""
+        "               getImage=\"btnSigstateLarge\""
         "               size=\"large\""
         "               getLabel=\"getSigLabel\""
         "               getScreentip=\"getSigTip\""
@@ -772,7 +775,7 @@ GetCustomUI_MIME (BSTR RibbonID, BSTR * RibbonXml)
         "     <group id=\"general_read\""
         "            label=\"%s\">"
         "       <button id=\"idSigned\""
-        "               getImage=\"btnSignLarge\""
+        "               getImage=\"btnSigstateLarge\""
         "               size=\"large\""
         "               getLabel=\"getSigLabel\""
         "               getScreentip=\"getSigTip\""
diff --git a/src/mail.cpp b/src/mail.cpp
index 4e06a88..0f6e20b 100644
--- a/src/mail.cpp
+++ b/src/mail.cpp
@@ -20,6 +20,7 @@
  */
 
 #include "config.h"
+#include "dialogs.h"
 #include "common.h"
 #include "mail.h"
 #include "eventsinks.h"
@@ -90,6 +91,8 @@ Mail::Mail (LPDISPATCH mailitem) :
     m_crypt_successful(false),
     m_is_smime(false),
     m_is_smime_checked(false),
+    m_is_signed(false),
+    m_is_valid(false),
     m_moss_position(0),
     m_sender(NULL),
     m_type(MSGTYPE_UNKNOWN)
@@ -127,9 +130,9 @@ Mail::~Mail()
       g_mail_map.erase (it);
     }
 
-  if (!m_uid.empty())
+  if (!m_uuid.empty())
     {
-      auto it2 = g_uid_map.find(m_uid);
+      auto it2 = g_uid_map.find(m_uuid);
       if (it2 != g_uid_map.end())
         {
           g_uid_map.erase (it2);
@@ -157,13 +160,13 @@ Mail::get_mail_for_item (LPDISPATCH mailitem)
 }
 
 Mail *
-Mail::get_mail_for_uid (const char *uid)
+Mail::get_mail_for_uuid (const char *uuid)
 {
-  if (!uid)
+  if (!uuid)
     {
       return NULL;
     }
-  auto it = g_uid_map.find(std::string(uid));
+  auto it = g_uid_map.find(std::string(uuid));
   if (it == g_uid_map.end())
     {
       return NULL;
@@ -481,7 +484,7 @@ Mail::decrypt_verify()
                  SRCNAME, __func__, m_mailitem);
       return 1;
     }
-  set_uid ();
+  set_uuid ();
   m_processed = true;
   /* Insert placeholder */
   char *placeholder_buf;
@@ -559,16 +562,22 @@ Mail::update_body()
 void
 Mail::parsing_done()
 {
+  TRACEPOINT;
   /* Store the results. */
   m_decrypt_result = m_parser->decrypt_result ();
   m_verify_result = m_parser->verify_result ();
+
+  update_sigstate ();
   m_needs_wipe = true;
 
+  TRACEPOINT;
   /* Set categories according to the result. */
   update_categories();
 
+  TRACEPOINT;
   /* Update the body */
   update_body();
+  TRACEPOINT;
 
   /* Update attachments */
   if (add_attachments (m_mailitem, m_parser->get_attachments()))
@@ -582,6 +591,7 @@ Mail::parsing_done()
   delete m_parser;
   m_parser = nullptr;
   gpgoladdin_invalidate_ui ();
+  TRACEPOINT;
   return;
 }
 
@@ -917,34 +927,34 @@ get_uid_for_sender (const Key k, const char *sender)
   return ret;
 }
 
-const std::pair <Signature, UserID>
-Mail::get_valid_sig ()
+void
+Mail::update_sigstate ()
 {
   const char *sender = get_sender();
-  std::pair <Signature, UserID> ret;
 
   if (!sender)
     {
       log_error ("%s:%s:%i", SRCNAME, __func__, __LINE__);
-      return ret;
+      return;
     }
 
   if (m_verify_result.isNull())
     {
       log_debug ("%s:%s: No verify result.",
                  SRCNAME, __func__);
-      return ret;
+      return;
     }
 
   if (m_verify_result.error())
     {
       log_debug ("%s:%s: verify error.",
                  SRCNAME, __func__);
-      return ret;
+      return;
     }
 
   for (const auto sig: m_verify_result.signatures())
     {
+      m_is_signed = true;
       if (sig.validity() != Signature::Validity::Marginal &&
           sig.validity() != Signature::Validity::Full &&
           sig.validity() != Signature::Validity::Ultimate)
@@ -981,18 +991,32 @@ Mail::get_valid_sig ()
         }
       log_debug ("%s:%s: Classified sender as verified",
                  SRCNAME, __func__);
-      return std::pair<Signature, UserID> (sig, uid);
+      m_sig = sig;
+      m_uid = uid;
+      m_is_valid = true;
     }
-  log_debug ("%s:%s: No signature with enough trust.",
+
+  log_debug ("%s:%s: No signature with enough trust. Using first",
              SRCNAME, __func__);
-  return ret;
+  m_sig = m_verify_result.signature(0);
+  return;
+}
+
+const std::pair <Signature, UserID>
+Mail::get_valid_sig ()
+{
+  std::pair <Signature, UserID> ret;
+  if (!m_is_valid)
+    {
+      return ret;
+    }
+  return std::pair<Signature, UserID> (m_sig, m_uid);
 }
 
 bool
 Mail::is_valid_sig ()
 {
-   const auto pair = get_valid_sig();
-   return !pair.first.isNull() && !pair.second.isNull();
+   return m_is_valid;
 }
 
 void
@@ -1031,23 +1055,23 @@ Mail::is_signed()
 }
 
 int
-Mail::set_uid()
+Mail::set_uuid()
 {
-  if (!m_uid.empty())
+  if (!m_uuid.empty())
     {
       return 0;
     }
-  char *uid = get_unique_id (m_mailitem, 1);
+  char *uuid = get_unique_id (m_mailitem, 1);
 
-  if (!uid)
+  if (!uuid)
     {
-      log_debug ("%s:%s: Failed to get uid for %p",
+      log_debug ("%s:%s: Failed to get uuid for %p",
                  SRCNAME, __func__, m_mailitem);
       return -1;
     }
-  m_uid = uid;
-  xfree (uid);
-  g_uid_map.insert (std::pair<std::string, Mail *> (m_uid, this));
+  m_uuid = uuid;
+  xfree (uuid);
+  g_uid_map.insert (std::pair<std::string, Mail *> (m_uuid, this));
   return 0;
 }
 
@@ -1107,6 +1131,7 @@ Mail::get_signature_status()
         }
       /* We only handle the first signature. */
       const auto sig = m_verify_result.signature (0);
+      isOpenPGP = sig.key().protocol() == Protocol::OpenPGP;
       keyFound = !(sig.summary() & Signature::Summary::KeyMissing);
 
       log_debug ("%s:%s: Formatting sig. Validity: %x Summary: %x",
@@ -1216,3 +1241,35 @@ Mail::get_signature_status()
   xfree (buf);
   return message;
 }
+
+int
+Mail::get_signature_icon_id () const
+{
+  if (!m_is_signed)
+    {
+      return IDI_EMBLEM_INFORMATION_64_PNG;
+    }
+  if (m_is_valid)
+    {
+      return IDI_EMBLEM_SUCCESS_64_PNG;
+    }
+  const auto sig = m_verify_result.signature (0);
+  if ((sig.summary() & Signature::Summary::KeyMissing))
+    {
+      return IDI_EMBLEM_QUESTION_64_PNG;
+    }
+
+  /* Maybe warning for unsigned and invalid sigs? */
+
+  return IDI_EMBLEM_INFORMATION_64_PNG;
+}
+
+const char*
+Mail::get_sig_fpr() const
+{
+  if (!m_is_signed || m_sig.isNull())
+    {
+      return nullptr;
+    }
+  return m_sig.fingerprint();
+}
diff --git a/src/parsecontroller.cpp b/src/parsecontroller.cpp
index a7fa842..8a69550 100644
--- a/src/parsecontroller.cpp
+++ b/src/parsecontroller.cpp
@@ -288,6 +288,7 @@ ParseController::parse()
              SRCNAME, __func__, m_decrypt_result.error().code(),
              m_verify_result.error().code());
 
+  TRACEPOINT;
   /* Ensure that the Keys for the signatures are available */
   for (const auto sig: m_verify_result.signatures())
     {
@@ -300,6 +301,7 @@ ParseController::parse()
        ss << m_decrypt_result << '\n' << m_verify_result;
        log_debug ("Decrypt / Verify result: %s", ss.str().c_str());
     }
+  TRACEPOINT;
 
   return;
 }
diff --git a/src/ribbon-callbacks.cpp b/src/ribbon-callbacks.cpp
index d38cfe3..2bb80e5 100644
--- a/src/ribbon-callbacks.cpp
+++ b/src/ribbon-callbacks.cpp
@@ -49,6 +49,11 @@
 #include "message.h"
 #include "mail.h"
 
+#include <gpgme++/context.h>
+#include <gpgme++/data.h>
+
+using namespace GpgME;
+
 #define OPAQUE_SIGNED_MARKER "-----BEGIN PGP MESSAGE-----"
 
 /* Gets the context of a ribbon control. And prints some
@@ -1468,7 +1473,7 @@ get_mail_from_control (LPDISPATCH ctrl)
       return NULL;
     }
 
-  auto ret = Mail::get_mail_for_uid (uid);
+  auto ret = Mail::get_mail_for_uuid (uid);
   xfree (uid);
   if (!ret)
     {
@@ -1481,7 +1486,7 @@ get_mail_from_control (LPDISPATCH ctrl)
 
 /* Helper to reduce code duplication.*/
 #define MY_MAIL_GETTER \
-  if (!ctrl || !result) \
+  if (!ctrl) \
     { \
       log_error ("%s:%s:%i", SRCNAME, __func__, __LINE__); \
       return E_FAIL; \
@@ -1571,9 +1576,74 @@ HRESULT get_sig_stip (LPDISPATCH ctrl, VARIANT *result)
   return S_OK;
 }
 
-HRESULT launch_cert_details (LPDISPATCH ctrl, VARIANT *result)
+HRESULT launch_cert_details (LPDISPATCH ctrl)
 {
-  (void) ctrl;
-  (void) result;
+  MY_MAIL_GETTER
+
+  if (!mail)
+    {
+      log_debug ("%s:%s: No mail.",
+                 SRCNAME, __func__);
+      return S_OK;
+    }
+
+  char *uiserver = get_uiserver_name ();
+  bool showError = false;
+  if (uiserver)
+    {
+      std::string path (uiserver);
+      xfree (uiserver);
+      if (path.find("kleopatra.exe") != std::string::npos)
+        {
+        size_t dpos;
+        if ((dpos = path.find(" --daemon")) != std::string::npos)
+            {
+              path.erase(dpos, strlen(" --daemon"));
+            }
+          auto ctx = Context::createForEngine(SpawnEngine);
+          if (!ctx)
+            {
+              log_error ("%s:%s: No spawn engine.",
+                         SRCNAME, __func__);
+            }
+            const char *argv[] = {path.c_str(),
+                                  "--query",
+                                  mail->get_sig_fpr(),
+                                  NULL };
+            log_debug ("%s:%s: Starting %s %s %s",
+                       SRCNAME, __func__, path.c_str(), argv[1], argv[2]);
+            Data d(Data::null);
+            ctx->spawnAsync(path.c_str(), argv, d, d,
+                            d, Context::SpawnNone);
+        }
+      else
+        {
+          showError = true;
+        }
+    }
+  else
+    {
+      showError = true;
+    }
+
+  if (showError)
+    {
+      MessageBox (NULL,
+                  _("Could not find Kleopatra.\n"
+                  "Please reinstall Gpg4win with the Kleopatra component enabled."),
+                  _("GpgOL"),
+                  MB_ICONINFORMATION|MB_OK);
+    }
   return S_OK;
 }
+
+HRESULT get_sigstate_icon (LPDISPATCH ctrl, VARIANT *result)
+{
+  MY_MAIL_GETTER
+
+  if (mail)
+    {
+      return getIcon (mail->get_signature_icon_id (), result);
+    }
+  return getIcon (IDI_EMBLEM_INFORMATION_64_PNG, result);
+}
diff --git a/src/ribbon-callbacks.h b/src/ribbon-callbacks.h
index 8dad389..be64eb5 100644
--- a/src/ribbon-callbacks.h
+++ b/src/ribbon-callbacks.h
@@ -51,6 +51,7 @@
 #define ID_GET_SIG_TTIP         26
 #define ID_GET_SIG_LABEL        27
 #define ID_LAUNCH_CERT_DETAILS  28
+#define ID_BTN_SIGSTATE_LARGE   29
 
 #define ID_BTN_CERTMANAGER       IDI_KEY_MANAGER_64_PNG
 #define ID_BTN_DECRYPT           IDI_DECRYPT_16_PNG
@@ -89,7 +90,9 @@ HRESULT get_sig_ttip (LPDISPATCH ctrl, VARIANT *result);
 /* Get the supertip for the signature. Returns BSTR */
 HRESULT get_sig_stip (LPDISPATCH ctrl, VARIANT *result);
 /* Show a certificate details dialog. Returns nothing. */
-HRESULT launch_cert_details (LPDISPATCH ctrl, VARIANT *result);
+HRESULT launch_cert_details (LPDISPATCH ctrl);
+/* Callback to get the sigstate icon. */
+HRESULT get_sigstate_icon (LPDISPATCH ctrl, VARIANT *result);
 /* Callback to get our own control reference */
 HRESULT ribbon_loaded (LPDISPATCH ctrl);
 #endif

commit 20dace4ab5dd5e3e0590929698767327d8e5db70
Author: Andre Heinecke <aheinecke at intevation.de>
Date:   Tue Oct 18 15:15:16 2016 +0200

    Add new icons for signature state
    
    * COPYING-ICONS,
    src/icons/Makefile.am,
    src/icons/README.icons,
    src/icons/emblem-information-64.png,
    src/icons/emblem-information.svg,
    src/icons/emblem-question-64.png,
    src/icons/emblem-question.svg,
    src/icons/emblem-success-64.png,
    src/icons/emblem-success.svg,
    src/icons/emblem-warning-64.png,
    src/icons/emblem-warning.svg: New.
    * src/dialogs.h, src/dialogs.rc: Add new ids / data.

diff --git a/COPYING-ICONS b/COPYING-ICONS
new file mode 100644
index 0000000..19f0a2e
--- /dev/null
+++ b/COPYING-ICONS
@@ -0,0 +1,213 @@
+Several icons used in GpgOL were taken from the Breeze / Oxygen Icon
+Theme. So for the Icons (and the combined package) the following
+copyright notice applies:
+
+The Breeze Icon Theme in src/icons/
+
+    Copyright (C) 2014 Uri Herrera <uri_herrera at nitrux.in> and others
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 3 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+
+Clarification:
+
+  The GNU Lesser General Public License or LGPL is written for
+  software libraries in the first place. We expressly want the LGPL to
+  be valid for this artwork library too.
+
+  KDE Breeze theme icons is a special kind of software library, it is an
+  artwork library, it's elements can be used in a Graphical User Interface, or
+  GUI.
+
+  Source code, for this library means:
+   - where they exist, SVG;
+   - otherwise, if applicable, the multi-layered formats xcf or psd, or
+  otherwise png.
+
+  The LGPL in some sections obliges you to make the files carry
+  notices. With images this is in some cases impossible or hardly useful.
+
+  With this library a notice is placed at a prominent place in the directory
+  containing the elements. You may follow this practice.
+
+  The exception in section 5 of the GNU Lesser General Public License covers
+  the use of elements of this art library in a GUI.
+
+ https://vdesign.kde.org/
+
+-----
+		   GNU LESSER GENERAL PUBLIC LICENSE
+                       Version 3, 29 June 2007
+
+ Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>
+ Everyone is permitted to copy and distribute verbatim copies
+ of this license document, but changing it is not allowed.
+
+
+  This version of the GNU Lesser General Public License incorporates
+the terms and conditions of version 3 of the GNU General Public
+License, supplemented by the additional permissions listed below.
+
+  0. Additional Definitions.
+
+  As used herein, "this License" refers to version 3 of the GNU Lesser
+General Public License, and the "GNU GPL" refers to version 3 of the GNU
+General Public License.
+
+  "The Library" refers to a covered work governed by this License,
+other than an Application or a Combined Work as defined below.
+
+  An "Application" is any work that makes use of an interface provided
+by the Library, but which is not otherwise based on the Library.
+Defining a subclass of a class defined by the Library is deemed a mode
+of using an interface provided by the Library.
+
+  A "Combined Work" is a work produced by combining or linking an
+Application with the Library.  The particular version of the Library
+with which the Combined Work was made is also called the "Linked
+Version".
+
+  The "Minimal Corresponding Source" for a Combined Work means the
+Corresponding Source for the Combined Work, excluding any source code
+for portions of the Combined Work that, considered in isolation, are
+based on the Application, and not on the Linked Version.
+
+  The "Corresponding Application Code" for a Combined Work means the
+object code and/or source code for the Application, including any data
+and utility programs needed for reproducing the Combined Work from the
+Application, but excluding the System Libraries of the Combined Work.
+
+  1. Exception to Section 3 of the GNU GPL.
+
+  You may convey a covered work under sections 3 and 4 of this License
+without being bound by section 3 of the GNU GPL.
+
+  2. Conveying Modified Versions.
+
+  If you modify a copy of the Library, and, in your modifications, a
+facility refers to a function or data to be supplied by an Application
+that uses the facility (other than as an argument passed when the
+facility is invoked), then you may convey a copy of the modified
+version:
+
+   a) under this License, provided that you make a good faith effort to
+   ensure that, in the event an Application does not supply the
+   function or data, the facility still operates, and performs
+   whatever part of its purpose remains meaningful, or
+
+   b) under the GNU GPL, with none of the additional permissions of
+   this License applicable to that copy.
+
+  3. Object Code Incorporating Material from Library Header Files.
+
+  The object code form of an Application may incorporate material from
+a header file that is part of the Library.  You may convey such object
+code under terms of your choice, provided that, if the incorporated
+material is not limited to numerical parameters, data structure
+layouts and accessors, or small macros, inline functions and templates
+(ten or fewer lines in length), you do both of the following:
+
+   a) Give prominent notice with each copy of the object code that the
+   Library is used in it and that the Library and its use are
+   covered by this License.
+
+   b) Accompany the object code with a copy of the GNU GPL and this license
+   document.
+
+  4. Combined Works.
+
+  You may convey a Combined Work under terms of your choice that,
+taken together, effectively do not restrict modification of the
+portions of the Library contained in the Combined Work and reverse
+engineering for debugging such modifications, if you also do each of
+the following:
+
+   a) Give prominent notice with each copy of the Combined Work that
+   the Library is used in it and that the Library and its use are
+   covered by this License.
+
+   b) Accompany the Combined Work with a copy of the GNU GPL and this license
+   document.
+
+   c) For a Combined Work that displays copyright notices during
+   execution, include the copyright notice for the Library among
+   these notices, as well as a reference directing the user to the
+   copies of the GNU GPL and this license document.
+
+   d) Do one of the following:
+
+       0) Convey the Minimal Corresponding Source under the terms of this
+       License, and the Corresponding Application Code in a form
+       suitable for, and under terms that permit, the user to
+       recombine or relink the Application with a modified version of
+       the Linked Version to produce a modified Combined Work, in the
+       manner specified by section 6 of the GNU GPL for conveying
+       Corresponding Source.
+
+       1) Use a suitable shared library mechanism for linking with the
+       Library.  A suitable mechanism is one that (a) uses at run time
+       a copy of the Library already present on the user's computer
+       system, and (b) will operate properly with a modified version
+       of the Library that is interface-compatible with the Linked
+       Version.
+
+   e) Provide Installation Information, but only if you would otherwise
+   be required to provide such information under section 6 of the
+   GNU GPL, and only to the extent that such information is
+   necessary to install and execute a modified version of the
+   Combined Work produced by recombining or relinking the
+   Application with a modified version of the Linked Version. (If
+   you use option 4d0, the Installation Information must accompany
+   the Minimal Corresponding Source and Corresponding Application
+   Code. If you use option 4d1, you must provide the Installation
+   Information in the manner specified by section 6 of the GNU GPL
+   for conveying Corresponding Source.)
+
+  5. Combined Libraries.
+
+  You may place library facilities that are a work based on the
+Library side by side in a single library together with other library
+facilities that are not Applications and are not covered by this
+License, and convey such a combined library under terms of your
+choice, if you do both of the following:
+
+   a) Accompany the combined library with a copy of the same work based
+   on the Library, uncombined with any other library facilities,
+   conveyed under the terms of this License.
+
+   b) Give prominent notice with the combined library that part of it
+   is a work based on the Library, and explaining where to find the
+   accompanying uncombined form of the same work.
+
+  6. Revised Versions of the GNU Lesser General Public License.
+
+  The Free Software Foundation may publish revised and/or new versions
+of the GNU Lesser General Public License from time to time. Such new
+versions will be similar in spirit to the present version, but may
+differ in detail to address new problems or concerns.
+
+  Each version is given a distinguishing version number. If the
+Library as you received it specifies that a certain numbered version
+of the GNU Lesser General Public License "or any later version"
+applies to it, you have the option of following the terms and
+conditions either of that published version or of any later version
+published by the Free Software Foundation. If the Library as you
+received it does not specify a version number of the GNU Lesser
+General Public License, you may choose any version of the GNU Lesser
+General Public License ever published by the Free Software Foundation.
+
+  If the Library as you received it specifies that a proxy can decide
+whether future versions of the GNU Lesser General Public License shall
+apply, that proxy's public statement of acceptance of any version is
+permanent authorization for you to choose that version for the
+Library.
diff --git a/src/dialogs.h b/src/dialogs.h
index 6b4f300..34da890 100644
--- a/src/dialogs.h
+++ b/src/dialogs.h
@@ -112,5 +112,9 @@
 #define IDI_ENCSIGN_FILE_48_PNG         0x6050
 #define IDI_SIGN_48_PNG                 0x6060
 #define IDI_VERIFY_48_PNG               0x6070
+#define IDI_EMBLEM_WARNING_64_PNG       0x6071
+#define IDI_EMBLEM_SUCCESS_64_PNG       0x6072
+#define IDI_EMBLEM_INFORMATION_64_PNG   0x6073
+#define IDI_EMBLEM_QUESTION_64_PNG      0x6074
 
 #endif /*DIALOGS_H*/
diff --git a/src/dialogs.rc b/src/dialogs.rc
index 5c975ad..d1d4abc 100644
--- a/src/dialogs.rc
+++ b/src/dialogs.rc
@@ -52,6 +52,11 @@ IDB_DECRYPT_VERIFY_16M    BITMAP  DISCARDABLE  "icons/decrypt-verify-16m.bmp"
 
 IDI_ENCSIGN_FILE_48_PNG   RCDATA               "icons/encrypt-sign-file-48.png"
 
+IDI_EMBLEM_WARNING_64_PNG RCDATA               "icons/emblem-warning-64.png"
+IDI_EMBLEM_SUCCESS_64_PNG RCDATA               "icons/emblem-success-64.png"
+IDI_EMBLEM_INFORMATION_64_PNG RCDATA           "icons/emblem-information-64.png"
+IDI_EMBLEM_QUESTION_64_PNG RCDATA              "icons/emblem-question-64.png"
+
 
 
 IDD_GPG_OPTIONS  DIALOG DISCARDABLE  0, 0, 266, 274
diff --git a/src/icons/Makefile.am b/src/icons/Makefile.am
new file mode 100644
index 0000000..cfe1261
--- /dev/null
+++ b/src/icons/Makefile.am
@@ -0,0 +1,29 @@
+# Makefile.am - makefile for GPGol icons
+# Copyright (C) 2016 Intevation GmbH
+#
+# This file is free software; as a special exception the author gives
+# unlimited permission to copy and/or distribute it, with or without
+# modifications, as long as this notice is preserved.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY, to the extent permitted by law; without even the
+# implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+
+## Process this file with automake to produce Makefile.in
+EXTRA_DIST= \
+    encrypt-16.bmp encrypt-16m.bmp \
+    sign-16.bmp sign-16m.bmp \
+    key-manager-16.bmp key-manager-16m.bmp \
+    decrypt-16.bmp decrypt-16m.bmp \
+    verify-16.bmp  verify-16m.bmp \
+    decrypt-verify-16.bmp decrypt-verify-16m.bmp \
+    encrypt-16.png encrypt-48.png \
+    key-manager-64.png \
+    decrypt-16.png decrypt-48.png \
+    encrypt-sign-file-48.png \
+    sign-48.png verify-48.png \
+    README.icons\
+    emblem-question-64.png \
+    emblem-warning-64.png \
+    emblem-success-64.png \
+    emblem-information-64.png
diff --git a/src/icons/README.icons b/src/icons/README.icons
index edf7fb8..ac55319 100644
--- a/src/icons/README.icons
+++ b/src/icons/README.icons
@@ -107,6 +107,13 @@ and those installed via the forms extensions from external files.
 
   6. Done.
 
+  3. SVG icons
+  ============
+
+  To convert svg icons to png it is suggested to use inkscape.
+
+  inkscape -w 64 -h 64 -e "<file>-64.png" "<file>.svg"
+
 
 That's all.  The output of the file(1) command should show something
 like this:
diff --git a/src/icons/emblem-information-64.png b/src/icons/emblem-information-64.png
new file mode 100644
index 0000000..cce8e5e
Binary files /dev/null and b/src/icons/emblem-information-64.png differ
diff --git a/src/icons/emblem-information.svg b/src/icons/emblem-information.svg
new file mode 100644
index 0000000..2deec9a
--- /dev/null
+++ b/src/icons/emblem-information.svg
@@ -0,0 +1,21 @@
+<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8">
+  <defs id="defs3051">
+    <style type="text/css" id="current-color-scheme">
+      .ColorScheme-Highlight {
+        color:#3daee9;
+      }
+      </style>
+  </defs>
+  <g
+     transform="translate(-7,-1037.3622)">
+    <path
+       style="fill:currentColor;fill-opacity:1;stroke:none"
+       d="m 15,1041.3622 a 4,4 0 0 1 -4,4 4,4 0 0 1 -4,-4 4,4 0 0 1 4,-4 4,4 0 0 1 4,4 z"
+       class="ColorScheme-Highlight" />
+    <path
+       style="opacity:1;fill:#ffffff;fill-opacity:1;stroke:none"
+       d="M 3.5 1 L 3.5 2 L 4.5 2 L 4.5 1 L 3.5 1 z M 3.5 3 L 3.5 7 L 4.5 7 L 4.5 3 L 3.5 3 z "
+       transform="translate(7,1037.3622)"
+       id="rect4241" />
+  </g>
+</svg>
diff --git a/src/icons/emblem-question-64.png b/src/icons/emblem-question-64.png
new file mode 100644
index 0000000..05c1312
Binary files /dev/null and b/src/icons/emblem-question-64.png differ
diff --git a/src/icons/emblem-question.svg b/src/icons/emblem-question.svg
new file mode 100644
index 0000000..f015e64
--- /dev/null
+++ b/src/icons/emblem-question.svg
@@ -0,0 +1,10 @@
+<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8">
+ <path
+     style="fill:#9b59b6;fill-opacity:1;stroke:none"
+     d="M 2 0 C 0.8919807 0 0 0.892 0 2 L 0 6 C 0 7.1081 0.8919807 8 2 8 L 6 8 C 7.108019 8 8 7.1081 8 6 L 8 2 C 8 0.892 7.108019 0 6 0 L 2 0 z "
+     />
+ <path
+     style="fill:#ffffff;fill-opacity:1;stroke:none"
+     d="M 4 1 C 3.51389 1 3.0599989 1.1705344 2.7402344 1.4902344 C 2.4204694 1.8100344 2.25 2.2639 2.25 2.75 L 3.25 2.75 C 3.25 2.4861 3.3295286 2.3149656 3.4472656 2.1972656 C 3.5650006 2.0795656 3.736112 2 4 2 C 4.26389 2 4.4349984 2.0799656 4.5527344 2.1972656 C 4.6704694 2.3149656 4.75 2.4861 4.75 2.75 C 4.75 2.9792 4.7048303 3.0776625 4.6445312 3.1640625 C 4.5842412 3.2500625 4.4849756 3.3305938 4.3378906 3.4335938 C 4.1908036 3.5364937 3.9968862 3.6547344 3.8164062 3.8652344 C 3.6359262 4.0758344 3.5 4.3959 3.5 4.75 L 3.5 5 L 4.5 5 L 4.5 4.75 C 4.5 4.6042 4.5203088 4.578525 4.5742188 4.515625 C 4.6281087 4.452625 4.7466934 4.3697062 4.9121094 4.2539062 C 5.0775214 4.1381062 5.2907638 3.983975 5.4648438 3.734375 C 5.6389238 3.484875 5.75 3.1458 5.75 2.75 C 5.75 2.2639 5.5795326 1.8100344 5.2597656 1.4902344 C 4.9400006 1.1705344 4.486112 1 4 1 z M 3.5 6 L 3.5 7 L 4.5 7 L 4.5 6 L 3.5 6 z "
+     />
+</svg>
diff --git a/src/icons/emblem-success-64.png b/src/icons/emblem-success-64.png
new file mode 100644
index 0000000..b955af1
Binary files /dev/null and b/src/icons/emblem-success-64.png differ
diff --git a/src/icons/emblem-success.svg b/src/icons/emblem-success.svg
new file mode 100644
index 0000000..faa74e3
--- /dev/null
+++ b/src/icons/emblem-success.svg
@@ -0,0 +1,18 @@
+<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8">
+  <defs id="defs3051">
+    <style type="text/css" id="current-color-scheme">
+      .ColorScheme-PositiveText {
+        color:#27ae60;
+      }
+      </style>
+  </defs>
+  <path
+      style="fill:currentColor;fill-opacity:1;stroke:none"
+     class="ColorScheme-PositiveText"
+    d="M 4 0 C 1.784 0 0 1.784 0 4 C 0 6.216 1.784 8 4 8 C 6.216 8 8 6.216 8 4 C 8 1.784 6.216 0 4 0 z "
+      />
+    <path
+       style="fill:#ffffff;fill-opacity:1;stroke:none"
+       d="M 6 2 L 3 5 L 2 4 L 1 5 L 2 6 L 3 7 L 7 3 L 6 2 z "
+        />
+</svg>
diff --git a/src/icons/emblem-warning-64.png b/src/icons/emblem-warning-64.png
new file mode 100644
index 0000000..31bbbb8
Binary files /dev/null and b/src/icons/emblem-warning-64.png differ
diff --git a/src/icons/emblem-warning.svg b/src/icons/emblem-warning.svg
new file mode 100644
index 0000000..1cad345
--- /dev/null
+++ b/src/icons/emblem-warning.svg
@@ -0,0 +1,18 @@
+<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 8 8">
+  <defs id="defs3051">
+    <style type="text/css" id="current-color-scheme">
+      .ColorScheme-NeutralText {
+        color:#f67400;
+      }
+      </style>
+  </defs>
+  <path
+      style="fill:currentColor;fill-opacity:1;stroke:none"
+     class="ColorScheme-NeutralText"
+    d="M 4 0 C 3.7964835 0.00025315917 3.644678 0.09649124 3.5371094 0.3125 C 3.5371094 0.3125 0.077246535 7.200596 0.080078125 7.2285156 C 0.043417505 7.3055016 -1.2456632e-05 7.403681 0 7.5 C 0 7.7761424 0.22385763 8 0.5 8 L 7.5 8 C 7.7761424 8 8 7.7761424 8 7.5 C 8.0002021 7.3873383 7.9818808 7.3677538 7.8925781 7.1894531 L 4.4550781 0.29101562 C 4.346001 0.097741395 4.1955491 -0.00033128801 4 0 z "
+      />
+    <path
+       style="fill:#ffffff;fill-opacity:1;stroke:none"
+       d="M 3.5 2 L 3.5 5 L 4.5 5 L 4.5 2 L 3.5 2 z M 3.5 6 L 3.5 7 L 4.5 7 L 4.5 6 L 3.5 6 z "
+        />
+</svg>

commit bdc38c2c812fc4806927d3a574bea55c568a90a6
Author: Andre Heinecke <aheinecke at intevation.de>
Date:   Tue Oct 18 14:53:24 2016 +0200

    Minor updates for readme
    
    * README: Update copyright and some text.

diff --git a/README b/README
index 8114264..3876d9c 100644
--- a/README
+++ b/README
@@ -1,12 +1,13 @@
-                         GpgOL Version 0.10.x
+                                GpgOL
                        =======================
           Copyright (C) 2004, 2005, 2007, 2008, 2009, 2010,
                         2011 g10 Code GmbH
-
+                        2013, 2015, 2016 Intevation GmbH
 
 GpgOL is a GnuPG plugin for MS Outlook.
 
-WARNING:  This version requires the decent version of Kleopatra or GPA.
+WARNING:  This version requires the decent version of Kleopatra or GPA
+for additional features and sending encrypted mail.
 
 
 .          Top directory with build scripts and information files.
@@ -30,10 +31,8 @@ compiled binary.
 If you are missing icons in the toolbar, checkout the toolbar's
 customize button - you will find the new icons there.
 
-Bug reporting: First click on the logo on the GnuPG options tab to
-check whether a newer version has been released - try this first.  If
-this does not help, check out the mailing lists and also the bug
-archive at http://bugs.gnupg.org (use username and password "guest",
-select "query" and there category "gpgol") if you did not found any
+Bug reporting: First check whether a newer version has been released -
+try this first.  If this does not help, check out the mailing lists
+and also the bug archive at http://bugs.gnupg.org if you did not find any
 information there please send a report, including all relevant version
 numbers to the address given at the top of this AUTHORS file.

commit 376084db0aa59c44a2ccc4e0f7878033fd76d2a6
Author: Andre Heinecke <aheinecke at intevation.de>
Date:   Tue Oct 18 14:16:04 2016 +0200

    Move get_uiserver_name into common
    
    * src/common.c (get_uiserver_name): Added.
    * src/common.h: Add prototype.
    * src/engine-assuan.c (get_uiserver_name): Removed.

diff --git a/src/common.c b/src/common.c
index 42598f9..777f085 100644
--- a/src/common.c
+++ b/src/common.c
@@ -853,3 +853,75 @@ format_date_from_gpgme (unsigned long time)
     }
   return wchar_to_utf8 (buf);
 }
+
+/* Return the name of the default UI server.  This name is used to
+   auto start an UI server if an initial connect failed.  */
+char *
+get_uiserver_name (void)
+{
+  char *name = NULL;
+  char *dir, *uiserver, *p;
+  int extra_arglen = 9;
+
+  const char * server_names[] = {"kleopatra.exe",
+                                 "bin\\kleopatra.exe",
+                                 "gpa.exe",
+                                 "bin\\gpa.exe",
+                                 NULL};
+  const char **tmp = NULL;
+
+  dir = get_gpg4win_dir ();
+  if (!dir)
+    {
+      log_error ("Failed to find gpg4win dir");
+      return NULL;
+    }
+  uiserver = read_w32_registry_string (NULL, GPG4WIN_REGKEY_3,
+                                       "UI Server");
+  if (!uiserver)
+    {
+      uiserver = read_w32_registry_string (NULL, GPG4WIN_REGKEY_2,
+                                           "UI Server");
+    }
+  if (uiserver)
+    {
+      name = xmalloc (strlen (dir) + strlen (uiserver) + extra_arglen + 2);
+      strcpy (stpcpy (stpcpy (name, dir), "\\"), uiserver);
+      for (p = name; *p; p++)
+        if (*p == '/')
+          *p = '\\';
+      xfree (uiserver);
+    }
+  if (name && !access (name, F_OK))
+    {
+      /* Set through registry and is accessible */
+      xfree(dir);
+      return name;
+    }
+  /* Fallbacks */
+  for (tmp = server_names; *tmp; tmp++)
+    {
+      if (name)
+        {
+          xfree (name);
+        }
+      name = xmalloc (strlen (dir) + strlen (*tmp) + extra_arglen + 2);
+      strcpy (stpcpy (stpcpy (name, dir), "\\"), *tmp);
+      for (p = name; *p; p++)
+        if (*p == '/')
+          *p = '\\';
+      if (!access (name, F_OK))
+        {
+          /* Found a viable candidate */
+          if (strstr (name, "kleopatra.exe"))
+            {
+              strcat (name, " --daemon");
+            }
+          xfree (dir);
+          return name;
+        }
+    }
+  xfree (dir);
+  log_error ("Failed to find a viable UIServer");
+  return NULL;
+}
diff --git a/src/common.h b/src/common.h
index 70b4ee7..796a8f8 100644
--- a/src/common.h
+++ b/src/common.h
@@ -116,8 +116,13 @@ char *percent_escape (const char *str, const char *extra);
 
 void fix_linebreaks (char *str, int *len);
 
+/* Format a date from gpgme (seconds since epoch)
+   with windows system locale. */
 char *format_date_from_gpgme (unsigned long time);
 
+/* Get the name of the uiserver */
+char *get_uiserver_name (void);
+
 /*-- main.c --*/
 const void *get_128bit_session_key (void);
 const void *get_64bit_session_marker (void);
diff --git a/src/engine-assuan.c b/src/engine-assuan.c
index 5375563..ac56d53 100644
--- a/src/engine-assuan.c
+++ b/src/engine-assuan.c
@@ -338,79 +338,6 @@ get_socket_name (void)
 }
 
 
-/* Return the name of the default UI server.  This name is used to
-   auto start an UI server if an initial connect failed.  */
-static char *
-get_uiserver_name (void)
-{
-  char *name = NULL;
-  char *dir, *uiserver, *p;
-  int extra_arglen = 9;
-
-  const char * server_names[] = {"kleopatra.exe",
-                                 "bin\\kleopatra.exe",
-                                 "gpa.exe",
-                                 "bin\\gpa.exe",
-                                 NULL};
-  const char **tmp = NULL;
-
-  dir = get_gpg4win_dir ();
-  if (!dir)
-    {
-      log_error ("Failed to find gpg4win dir");
-      return NULL;
-    }
-  uiserver = read_w32_registry_string (NULL, GPG4WIN_REGKEY_3,
-                                       "UI Server");
-  if (!uiserver)
-    {
-      uiserver = read_w32_registry_string (NULL, GPG4WIN_REGKEY_2,
-                                           "UI Server");
-    }
-  if (uiserver)
-    {
-      name = xmalloc (strlen (dir) + strlen (uiserver) + extra_arglen + 2);
-      strcpy (stpcpy (stpcpy (name, dir), "\\"), uiserver);
-      for (p = name; *p; p++)
-        if (*p == '/')
-          *p = '\\';
-      xfree (uiserver);
-    }
-  if (name && !access (name, F_OK))
-    {
-      /* Set through registry and is accessible */
-      xfree(dir);
-      return name;
-    }
-  /* Fallbacks */
-  for (tmp = server_names; *tmp; tmp++)
-    {
-      if (name)
-        {
-          xfree (name);
-        }
-      name = xmalloc (strlen (dir) + strlen (*tmp) + extra_arglen + 2);
-      strcpy (stpcpy (stpcpy (name, dir), "\\"), *tmp);
-      for (p = name; *p; p++)
-        if (*p == '/')
-          *p = '\\';
-      if (!access (name, F_OK))
-        {
-          /* Found a viable candidate */
-          if (strstr (name, "kleopatra.exe"))
-            {
-              strcat (name, " --daemon");
-            }
-          xfree (dir);
-          return name;
-        }
-    }
-  xfree (dir);
-  log_error ("Failed to find a viable UIServer");
-  return NULL;
-}
-
-
 static gpg_error_t
 send_one_option (assuan_context_t ctx, const char *name, const char *value)
 {

-----------------------------------------------------------------------

Summary of changes:
 COPYING-ICONS                       | 213 ++++++++++++++++++++++++++++++++++++
 README                              |  15 ++-
 src/common.c                        |  72 ++++++++++++
 src/common.h                        |   5 +
 src/dialogs.h                       |   4 +
 src/dialogs.rc                      |   5 +
 src/engine-assuan.c                 |  73 ------------
 src/gpgoladdin.cpp                  |   9 +-
 src/icons/Makefile.am               |  29 +++++
 src/icons/README.icons              |   7 ++
 src/icons/emblem-information-64.png | Bin 0 -> 1266 bytes
 src/icons/emblem-information.svg    |  21 ++++
 src/icons/emblem-question-64.png    | Bin 0 -> 1518 bytes
 src/icons/emblem-question.svg       |  10 ++
 src/icons/emblem-success-64.png     | Bin 0 -> 1462 bytes
 src/icons/emblem-success.svg        |  18 +++
 src/icons/emblem-warning-64.png     | Bin 0 -> 1117 bytes
 src/icons/emblem-warning.svg        |  18 +++
 src/mail.cpp                        | 107 +++++++++++++-----
 src/mail.h                          |  27 +++--
 src/parsecontroller.cpp             |   2 +
 src/ribbon-callbacks.cpp            |  80 +++++++++++++-
 src/ribbon-callbacks.h              |   5 +-
 23 files changed, 598 insertions(+), 122 deletions(-)
 create mode 100644 COPYING-ICONS
 create mode 100644 src/icons/Makefile.am
 create mode 100644 src/icons/emblem-information-64.png
 create mode 100644 src/icons/emblem-information.svg
 create mode 100644 src/icons/emblem-question-64.png
 create mode 100644 src/icons/emblem-question.svg
 create mode 100644 src/icons/emblem-success-64.png
 create mode 100644 src/icons/emblem-success.svg
 create mode 100644 src/icons/emblem-warning-64.png
 create mode 100644 src/icons/emblem-warning.svg


hooks/post-receive
diff --git a/src/mail.h b/src/mail.h
index e715504..9b8527a 100644
--- a/src/mail.h
+++ b/src/mail.h
@@ -63,14 +63,14 @@ public:
   */
   static Mail* get_mail_for_item (LPDISPATCH mailitem);
 
   /** @brief looks for existing Mail objects in the uid map.
     Only objects for which set_uid has been called can be found
-    in the uid map. Get the UID of a mailitem thorugh get_unique_id
+    in the uid map. Get the Unique ID of a mailitem thorugh get_unique_id
 
     @returns A reference to an existing mailitem or NULL in case none
     could be found.
   */
-  static Mail* get_mail_for_uid (const char *uid);
+  static Mail* get_mail_for_uuid (const char *uuid);
 
   /** @brief looks for existing Mail objects.
 
@@ -222,19 +222,28 @@ public:
 
   /** Get UID gets UniqueID property of this mail. Returns
     an empty string if the uid was not set with set uid.*/
-  const std::string & get_uid () const { return m_uid; }
+  const std::string & get_uuid () const { return m_uuid; }
 
   /** Returns 0 on success if the mail has a uid alrady or sets
     the uid. Setting only succeeds if the OOM is currently
     accessible. Returns -1 on error. */
-  int set_uid ();
+  int set_uuid ();
 
   /** Returns a localized string describing the signature state
     of this mail. */
   std::string get_signature_status ();
+
+  /** Get the icon id of the appropiate icon for this mail */
+  int get_signature_icon_id () const;
+
+  /** Get the fingerprint of an associated signature or null
+      if it is not signed. */
+  const char *get_sig_fpr() const;
+
 private:
   void update_categories ();
   void update_body ();
+  void update_sigstate ();
 
   LPDISPATCH m_mailitem;
   LPDISPATCH m_event_sink;
@@ -243,13 +252,17 @@ private:
        m_needs_save,   /* A property was changed but not by us. */
        m_crypt_successful, /* We successfuly performed crypto on the item. */
        m_is_smime, /* This is an smime mail. */
-       m_is_smime_checked; /* it was checked if this is an smime mail */
+       m_is_smime_checked, /* it was checked if this is an smime mail */
+       m_is_signed, /* Mail is signed */
+       m_is_valid; /* Mail is valid signed. */
   int m_moss_position; /* The number of the original message attachment. */
   char *m_sender;
   msgtype_t m_type; /* Our messagetype as set in mapi */
   ParseController *m_parser;
   GpgME::VerificationResult m_verify_result;
   GpgME::DecryptionResult m_decrypt_result;
-  std::string m_uid;
+  GpgME::Signature m_sig;
+  GpgME::UserID m_uid;
+  std::string m_uuid;
 };
 #endif // MAIL_H
@@ -63,14 +63,14 @@ public:
   static Mail* get_mail_for_item (LPDISPATCH mailitem);
 
-  /** @brief looks for existing Mail objects in the uid map.
+  /** @brief looks for existing Mail objects in the uuid map.
     Only objects for which set_uid has been called can be found
-- 
GnuPG extension for MS Outlook
http://git.gnupg.org




More information about the Gnupg-commits mailing list